// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "akonadicalendarplugin_debug.h"


Q_LOGGING_CATEGORY(AKONADICALENDARPLUGIN_LOG, "org.kde.kcalendarcore.akonadiplugin", QtInfoMsg)

