/****************************************************************************
** Meta object code from reading C++ file 'itiphandlerhelper_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../akonadi-calendar-26.04.3/src/itiphandlerhelper_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'itiphandlerhelper_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Akonadi17ITIPHandlerHelperE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi::ITIPHandlerHelper::qt_create_metaobjectdata<qt_meta_tag_ZN7Akonadi17ITIPHandlerHelperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi::ITIPHandlerHelper",
        "finished",
        "",
        "Akonadi::ITIPHandlerHelper::SendResult",
        "result",
        "errorMessage",
        "sendIncidenceDeletedMessageFinished",
        "KCalendarCore::iTIPMethod",
        "method",
        "KCalendarCore::Incidence::Ptr",
        "incidence",
        "sendIncidenceModifiedMessageFinished",
        "sendIncidenceCreatedMessageFinished",
        "onSchedulerFinished",
        "Akonadi::Scheduler::Result",
        "errorMsg",
        "slotIncidenceDeletedDialogClosed",
        "slotIncidenceModifiedDialogClosed",
        "slotIncidenceCreatedDialogClosed",
        "slotSchedulerFinishDialog"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'finished'
        QtMocHelpers::SignalData<void(Akonadi::ITIPHandlerHelper::SendResult, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 },
        }}),
        // Signal 'sendIncidenceDeletedMessageFinished'
        QtMocHelpers::SignalData<void(Akonadi::ITIPHandlerHelper::SendResult, KCalendarCore::iTIPMethod, const KCalendarCore::Incidence::Ptr &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Signal 'sendIncidenceModifiedMessageFinished'
        QtMocHelpers::SignalData<void(Akonadi::ITIPHandlerHelper::SendResult, KCalendarCore::iTIPMethod, const KCalendarCore::Incidence::Ptr &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Signal 'sendIncidenceCreatedMessageFinished'
        QtMocHelpers::SignalData<void(Akonadi::ITIPHandlerHelper::SendResult, KCalendarCore::iTIPMethod, const KCalendarCore::Incidence::Ptr &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'onSchedulerFinished'
        QtMocHelpers::SlotData<void(Akonadi::Scheduler::Result, const QString &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 4 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'slotIncidenceDeletedDialogClosed'
        QtMocHelpers::SlotData<void(const int, KCalendarCore::iTIPMethod, const KCalendarCore::Incidence::Ptr &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'slotIncidenceModifiedDialogClosed'
        QtMocHelpers::SlotData<void(const int, KCalendarCore::iTIPMethod, const KCalendarCore::Incidence::Ptr &)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'slotIncidenceCreatedDialogClosed'
        QtMocHelpers::SlotData<void(const int, KCalendarCore::iTIPMethod, const KCalendarCore::Incidence::Ptr &)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'slotSchedulerFinishDialog'
        QtMocHelpers::SlotData<void(const int, KCalendarCore::iTIPMethod, const KCalendarCore::Incidence::Ptr &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 4 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ITIPHandlerHelper, qt_meta_tag_ZN7Akonadi17ITIPHandlerHelperE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Akonadi::ITIPHandlerHelper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi17ITIPHandlerHelperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi17ITIPHandlerHelperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Akonadi17ITIPHandlerHelperE_t>.metaTypes,
    nullptr
} };

void Akonadi::ITIPHandlerHelper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ITIPHandlerHelper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->finished((*reinterpret_cast<std::add_pointer_t<Akonadi::ITIPHandlerHelper::SendResult>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->sendIncidenceDeletedMessageFinished((*reinterpret_cast<std::add_pointer_t<Akonadi::ITIPHandlerHelper::SendResult>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KCalendarCore::iTIPMethod>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::Ptr>>(_a[3]))); break;
        case 2: _t->sendIncidenceModifiedMessageFinished((*reinterpret_cast<std::add_pointer_t<Akonadi::ITIPHandlerHelper::SendResult>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KCalendarCore::iTIPMethod>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::Ptr>>(_a[3]))); break;
        case 3: _t->sendIncidenceCreatedMessageFinished((*reinterpret_cast<std::add_pointer_t<Akonadi::ITIPHandlerHelper::SendResult>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KCalendarCore::iTIPMethod>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::Ptr>>(_a[3]))); break;
        case 4: _t->onSchedulerFinished((*reinterpret_cast<std::add_pointer_t<Akonadi::Scheduler::Result>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->slotIncidenceDeletedDialogClosed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KCalendarCore::iTIPMethod>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::Ptr>>(_a[3]))); break;
        case 6: _t->slotIncidenceModifiedDialogClosed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KCalendarCore::iTIPMethod>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::Ptr>>(_a[3]))); break;
        case 7: _t->slotIncidenceCreatedDialogClosed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KCalendarCore::iTIPMethod>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::Ptr>>(_a[3]))); break;
        case 8: _t->slotSchedulerFinishDialog((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KCalendarCore::iTIPMethod>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::Ptr>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ITIPHandlerHelper::*)(Akonadi::ITIPHandlerHelper::SendResult , const QString & )>(_a, &ITIPHandlerHelper::finished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ITIPHandlerHelper::*)(Akonadi::ITIPHandlerHelper::SendResult , KCalendarCore::iTIPMethod , const KCalendarCore::Incidence::Ptr & )>(_a, &ITIPHandlerHelper::sendIncidenceDeletedMessageFinished, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ITIPHandlerHelper::*)(Akonadi::ITIPHandlerHelper::SendResult , KCalendarCore::iTIPMethod , const KCalendarCore::Incidence::Ptr & )>(_a, &ITIPHandlerHelper::sendIncidenceModifiedMessageFinished, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ITIPHandlerHelper::*)(Akonadi::ITIPHandlerHelper::SendResult , KCalendarCore::iTIPMethod , const KCalendarCore::Incidence::Ptr & )>(_a, &ITIPHandlerHelper::sendIncidenceCreatedMessageFinished, 3))
            return;
    }
}

const QMetaObject *Akonadi::ITIPHandlerHelper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi::ITIPHandlerHelper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi17ITIPHandlerHelperE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Akonadi::ITIPHandlerHelper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Akonadi::ITIPHandlerHelper::finished(Akonadi::ITIPHandlerHelper::SendResult _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Akonadi::ITIPHandlerHelper::sendIncidenceDeletedMessageFinished(Akonadi::ITIPHandlerHelper::SendResult _t1, KCalendarCore::iTIPMethod _t2, const KCalendarCore::Incidence::Ptr & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void Akonadi::ITIPHandlerHelper::sendIncidenceModifiedMessageFinished(Akonadi::ITIPHandlerHelper::SendResult _t1, KCalendarCore::iTIPMethod _t2, const KCalendarCore::Incidence::Ptr & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void Akonadi::ITIPHandlerHelper::sendIncidenceCreatedMessageFinished(Akonadi::ITIPHandlerHelper::SendResult _t1, KCalendarCore::iTIPMethod _t2, const KCalendarCore::Incidence::Ptr & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
