/****************************************************************************
** Meta object code from reading C++ file 'freebusyprovideradaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "freebusyprovideradaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'freebusyprovideradaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN32Akonadi__FreeBusyProviderAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi__FreeBusyProviderAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN32Akonadi__FreeBusyProviderAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi__FreeBusyProviderAdaptor",
        "D-Bus Interface",
        "org.freedesktop.Akonadi.Resource.FreeBusyProvider",
        "D-Bus Introspection",
        "  <interface name=\"org.freedesktop.Akonadi.Resource.FreeBusyProvi"
        "der\">\n    <method name=\"lastCacheUpdate\">\n      <arg directio"
        "n=\"out\" type=\"((iii)(iiii)i)\"/>\n      <annotation value=\"QDa"
        "teTime\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n    </me"
        "thod>\n    <method name=\"canHandleFreeBusy\">\n      <arg directi"
        "on=\"in\" type=\"s\" name=\"email\"/>\n      <annotation value=\"t"
        "rue\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </method"
        ">\n    <method name=\"retrieveFreeBusy\">\n      <arg direction=\""
        "in\" type=\"s\" name=\"email\"/>\n      <arg direction=\"in\" type"
        "=\"((iii)(iiii)i)\" name=\"start\"/>\n      <arg direction=\"in\" "
        "type=\"((iii)(iiii)i)\" name=\"end\"/>\n      <annotation value=\""
        "QDateTime\" name=\"org.qtproject.QtDBus.QtTypeName.In1\"/>\n      "
        "<annotation value=\"QDateTime\" name=\"org.qtproject.QtDBus.QtType"
        "Name.In2\"/>\n      <annotation value=\"true\" name=\"org.freedesk"
        "top.DBus.Method.NoReply\"/>\n    </method>\n    <signal name=\"han"
        "dlesFreeBusy\">\n      <arg direction=\"out\" type=\"s\" name=\"em"
        "ail\"/>\n      <arg direction=\"out\" type=\"b\" name=\"handles\"/"
        ">\n    </signal>\n    <signal name=\"freeBusyRetrieved\">\n      <"
        "arg direction=\"out\" type=\"s\" name=\"email\"/>\n      <arg dire"
        "ction=\"out\" type=\"s\" name=\"freeBusy\"/>\n      <arg direction"
        "=\"out\" type=\"b\" name=\"success\"/>\n      <arg direction=\"out"
        "\" type=\"s\" name=\"errorText\"/>\n    </signal>\n  </interface>\n",
        "freeBusyRetrieved",
        "",
        "email",
        "freeBusy",
        "success",
        "errorText",
        "handlesFreeBusy",
        "handles",
        "canHandleFreeBusy",
        "Q_NOREPLY",
        "lastCacheUpdate",
        "retrieveFreeBusy",
        "start",
        "end"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'freeBusyRetrieved'
        QtMocHelpers::SignalData<void(const QString &, const QString &, bool, const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 }, { QMetaType::Bool, 9 }, { QMetaType::QString, 10 },
        }}),
        // Signal 'handlesFreeBusy'
        QtMocHelpers::SignalData<void(const QString &, bool)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::Bool, 12 },
        }}),
        // Slot 'canHandleFreeBusy'
        QtMocHelpers::SlotData<void(const QString &)>(13, 14, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'lastCacheUpdate'
        QtMocHelpers::SlotData<QDateTime()>(15, 6, QMC::AccessPublic, QMetaType::QDateTime),
        // Slot 'retrieveFreeBusy'
        QtMocHelpers::SlotData<void(const QString &, const QDateTime &, const QDateTime &)>(16, 14, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QDateTime, 17 }, { QMetaType::QDateTime, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Akonadi__FreeBusyProviderAdaptor, qt_meta_tag_ZN32Akonadi__FreeBusyProviderAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Akonadi__FreeBusyProviderAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32Akonadi__FreeBusyProviderAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32Akonadi__FreeBusyProviderAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN32Akonadi__FreeBusyProviderAdaptorE_t>.metaTypes,
    nullptr
} };

void Akonadi__FreeBusyProviderAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Akonadi__FreeBusyProviderAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->freeBusyRetrieved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 1: _t->handlesFreeBusy((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 2: _t->canHandleFreeBusy((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: { QDateTime _r = _t->lastCacheUpdate();
            if (_a[0]) *reinterpret_cast<QDateTime*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->retrieveFreeBusy((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Akonadi__FreeBusyProviderAdaptor::*)(const QString & , const QString & , bool , const QString & )>(_a, &Akonadi__FreeBusyProviderAdaptor::freeBusyRetrieved, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Akonadi__FreeBusyProviderAdaptor::*)(const QString & , bool )>(_a, &Akonadi__FreeBusyProviderAdaptor::handlesFreeBusy, 1))
            return;
    }
}

const QMetaObject *Akonadi__FreeBusyProviderAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi__FreeBusyProviderAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32Akonadi__FreeBusyProviderAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int Akonadi__FreeBusyProviderAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void Akonadi__FreeBusyProviderAdaptor::freeBusyRetrieved(const QString & _t1, const QString & _t2, bool _t3, const QString & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 1
void Akonadi__FreeBusyProviderAdaptor::handlesFreeBusy(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
