/****************************************************************************
** Meta object code from reading C++ file 'freebusymanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../akonadi-calendar-26.04.3/src/freebusymanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'freebusymanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Akonadi15FreeBusyManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi::FreeBusyManager::qt_create_metaobjectdata<qt_meta_tag_ZN7Akonadi15FreeBusyManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi::FreeBusyManager",
        "freeBusyRetrieved",
        "",
        "KCalendarCore::FreeBusy::Ptr",
        "fb",
        "email",
        "checkFreeBusyUrl",
        "processFreeBusyDownloadResult",
        "KJob*",
        "processFreeBusyUploadResult",
        "processRetrieveQueue",
        "uploadFreeBusy",
        "publishFreeBusy",
        "QWidget*",
        "parentWidget",
        "mailFreeBusy",
        "daysToPublish",
        "retrieveFreeBusy",
        "forceDownload"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'freeBusyRetrieved'
        QtMocHelpers::SignalData<void(const KCalendarCore::FreeBusy::Ptr &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 },
        }}),
        // Slot 'checkFreeBusyUrl'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'processFreeBusyDownloadResult'
        QtMocHelpers::SlotData<void(KJob *)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Slot 'processFreeBusyUploadResult'
        QtMocHelpers::SlotData<void(KJob *)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Slot 'processRetrieveQueue'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'uploadFreeBusy'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'publishFreeBusy'
        QtMocHelpers::MethodData<void(QWidget *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Method 'publishFreeBusy'
        QtMocHelpers::MethodData<void()>(12, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'mailFreeBusy'
        QtMocHelpers::MethodData<void(int, QWidget *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 }, { 0x80000000 | 13, 14 },
        }}),
        // Method 'mailFreeBusy'
        QtMocHelpers::MethodData<void(int)>(15, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Method 'mailFreeBusy'
        QtMocHelpers::MethodData<void()>(15, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'retrieveFreeBusy'
        QtMocHelpers::MethodData<bool(const QString &, bool, QWidget *)>(17, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 5 }, { QMetaType::Bool, 18 }, { 0x80000000 | 13, 14 },
        }}),
        // Method 'retrieveFreeBusy'
        QtMocHelpers::MethodData<bool(const QString &, bool)>(17, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QString, 5 }, { QMetaType::Bool, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FreeBusyManager, qt_meta_tag_ZN7Akonadi15FreeBusyManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Akonadi::FreeBusyManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi15FreeBusyManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi15FreeBusyManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Akonadi15FreeBusyManagerE_t>.metaTypes,
    nullptr
} };

void Akonadi::FreeBusyManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FreeBusyManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->freeBusyRetrieved((*reinterpret_cast<std::add_pointer_t<KCalendarCore::FreeBusy::Ptr>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->d_ptr->checkFreeBusyUrl(); break;
        case 2: _t->d_ptr->processFreeBusyDownloadResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 3: _t->d_ptr->processFreeBusyUploadResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 4: _t->d_ptr->processRetrieveQueue(); break;
        case 5: _t->d_ptr->uploadFreeBusy(); break;
        case 6: _t->publishFreeBusy((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 7: _t->publishFreeBusy(); break;
        case 8: _t->mailFreeBusy((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[2]))); break;
        case 9: _t->mailFreeBusy((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->mailFreeBusy(); break;
        case 11: { bool _r = _t->retrieveFreeBusy((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->retrieveFreeBusy((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KCalendarCore::FreeBusy::Ptr >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FreeBusyManager::*)(const KCalendarCore::FreeBusy::Ptr & , const QString & )>(_a, &FreeBusyManager::freeBusyRetrieved, 0))
            return;
    }
}

const QMetaObject *Akonadi::FreeBusyManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi::FreeBusyManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi15FreeBusyManagerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KCalendarCore::FreeBusyCache"))
        return static_cast< KCalendarCore::FreeBusyCache*>(this);
    return QObject::qt_metacast(_clname);
}

int Akonadi::FreeBusyManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void Akonadi::FreeBusyManager::freeBusyRetrieved(const KCalendarCore::FreeBusy::Ptr & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}
QT_WARNING_POP
