/********************************************************************************
** Form generated from reading UI file 'publishdialog_base.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PUBLISHDIALOG_BASE_H
#define UI_PUBLISHDIALOG_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_PublishDialog_base
{
public:
    QGridLayout *gridLayout_2;
    QListWidget *mListWidget;
    QVBoxLayout *verticalLayout_2;
    QVBoxLayout *verticalLayout;
    QPushButton *mNew;
    QPushButton *mRemove;
    QPushButton *mSelectAddressee;
    QSpacerItem *spacerItem;
    QGridLayout *gridLayout;
    QLabel *TextLabel1;
    QLineEdit *mNameLineEdit;
    QLabel *TextLabel2;
    QLineEdit *mEmailLineEdit;

    void setupUi(QWidget *PublishDialog_base)
    {
        if (PublishDialog_base->objectName().isEmpty())
            PublishDialog_base->setObjectName("PublishDialog_base");
        PublishDialog_base->resize(410, 340);
        gridLayout_2 = new QGridLayout(PublishDialog_base);
        gridLayout_2->setSpacing(6);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        mListWidget = new QListWidget(PublishDialog_base);
        mListWidget->setObjectName("mListWidget");
        mListWidget->setMinimumSize(QSize(300, 250));

        gridLayout_2->addWidget(mListWidget, 0, 0, 1, 1);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        mNew = new QPushButton(PublishDialog_base);
        mNew->setObjectName("mNew");

        verticalLayout->addWidget(mNew);

        mRemove = new QPushButton(PublishDialog_base);
        mRemove->setObjectName("mRemove");

        verticalLayout->addWidget(mRemove);

        mSelectAddressee = new QPushButton(PublishDialog_base);
        mSelectAddressee->setObjectName("mSelectAddressee");

        verticalLayout->addWidget(mSelectAddressee);


        verticalLayout_2->addLayout(verticalLayout);

        spacerItem = new QSpacerItem(14, 258, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(spacerItem);


        gridLayout_2->addLayout(verticalLayout_2, 0, 1, 2, 1);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        TextLabel1 = new QLabel(PublishDialog_base);
        TextLabel1->setObjectName("TextLabel1");

        gridLayout->addWidget(TextLabel1, 0, 0, 1, 1);

        mNameLineEdit = new QLineEdit(PublishDialog_base);
        mNameLineEdit->setObjectName("mNameLineEdit");
        mNameLineEdit->setProperty("ClearButtonEnabled", QVariant(true));

        gridLayout->addWidget(mNameLineEdit, 0, 1, 1, 1);

        TextLabel2 = new QLabel(PublishDialog_base);
        TextLabel2->setObjectName("TextLabel2");

        gridLayout->addWidget(TextLabel2, 1, 0, 1, 1);

        mEmailLineEdit = new QLineEdit(PublishDialog_base);
        mEmailLineEdit->setObjectName("mEmailLineEdit");
        mEmailLineEdit->setProperty("ClearButtonEnabled", QVariant(true));

        gridLayout->addWidget(mEmailLineEdit, 1, 1, 1, 1);


        gridLayout_2->addLayout(gridLayout, 1, 0, 1, 1);

#if QT_CONFIG(shortcut)
        TextLabel1->setBuddy(mNameLineEdit);
        TextLabel2->setBuddy(mEmailLineEdit);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(mListWidget, mNew);
        QWidget::setTabOrder(mNew, mRemove);
        QWidget::setTabOrder(mRemove, mSelectAddressee);
        QWidget::setTabOrder(mSelectAddressee, mNameLineEdit);
        QWidget::setTabOrder(mNameLineEdit, mEmailLineEdit);

        retranslateUi(PublishDialog_base);

        QMetaObject::connectSlotsByName(PublishDialog_base);
    } // setupUi

    void retranslateUi(QWidget *PublishDialog_base)
    {
#if QT_CONFIG(tooltip)
        mListWidget->setToolTip(tr2i18n("The list of addressees to receive the invitation", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mListWidget->setWhatsThis(tr2i18n("This is a list of all the addresses you have currently selected to receive the iCalendar invitation.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        mNew->setToolTip(tr2i18n("Create a new recipient", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mNew->setWhatsThis(tr2i18n("Click this button and you will be able to enter a name and email for a new addressee to add to the recipients list", nullptr));
#endif // QT_CONFIG(whatsthis)
        mNew->setText(tr2i18n("&New", nullptr));
#if QT_CONFIG(tooltip)
        mRemove->setToolTip(tr2i18n("Remove the recipient currently selected", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mRemove->setWhatsThis(tr2i18n("Click this button to remove the recipient currently selected from the list", nullptr));
#endif // QT_CONFIG(whatsthis)
        mRemove->setText(tr2i18n("&Remove", nullptr));
#if QT_CONFIG(tooltip)
        mSelectAddressee->setToolTip(tr2i18n("Select a recipient from your address book", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mSelectAddressee->setWhatsThis(tr2i18n("Click this button to show another dialog where you will be able to select a recipient from your address book", nullptr));
#endif // QT_CONFIG(whatsthis)
        mSelectAddressee->setText(tr2i18n("&Select\342\200\246", nullptr));
        TextLabel1->setText(tr2i18n("Name:", "recipient name"));
#if QT_CONFIG(tooltip)
        mNameLineEdit->setToolTip(tr2i18n("The recipient's name", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mNameLineEdit->setWhatsThis(tr2i18n("This field contains the name of the recipient", nullptr));
#endif // QT_CONFIG(whatsthis)
        TextLabel2->setText(tr2i18n("E&mail:", "recipient email"));
#if QT_CONFIG(tooltip)
        mEmailLineEdit->setToolTip(tr2i18n("The recipient's email address", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mEmailLineEdit->setWhatsThis(tr2i18n("This field contains the email address of the recipient", nullptr));
#endif // QT_CONFIG(whatsthis)
        mEmailLineEdit->setText(QString());
        (void)PublishDialog_base;
    } // retranslateUi

};

namespace Ui {
    class PublishDialog_base: public Ui_PublishDialog_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PUBLISHDIALOG_BASE_H

