// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "serializer_debug.h"


Q_LOGGING_CATEGORY(AKONADI_SERIALIZER_CALENDAR_LOG, "org.kde.pim.calendar_serializer", QtInfoMsg)

