/****************************************************************************
** Meta object code from reading C++ file 'etmcalendar_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../akonadi-calendar-26.04.3/src/etmcalendar_p.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSet>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'etmcalendar_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Akonadi19CheckableProxyModelE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi::CheckableProxyModel::qt_create_metaobjectdata<qt_meta_tag_ZN7Akonadi19CheckableProxyModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi::CheckableProxyModel",
        "checkedByUser",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'checkedByUser'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CheckableProxyModel, qt_meta_tag_ZN7Akonadi19CheckableProxyModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Akonadi::CheckableProxyModel::staticMetaObject = { {
    QMetaObject::SuperData::link<KCheckableProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi19CheckableProxyModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi19CheckableProxyModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Akonadi19CheckableProxyModelE_t>.metaTypes,
    nullptr
} };

void Akonadi::CheckableProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CheckableProxyModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->checkedByUser(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CheckableProxyModel::*)()>(_a, &CheckableProxyModel::checkedByUser, 0))
            return;
    }
}

const QMetaObject *Akonadi::CheckableProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi::CheckableProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi19CheckableProxyModelE_t>.strings))
        return static_cast<void*>(this);
    return KCheckableProxyModel::qt_metacast(_clname);
}

int Akonadi::CheckableProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KCheckableProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void Akonadi::CheckableProxyModel::checkedByUser()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN7Akonadi18ETMCalendarPrivateE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi::ETMCalendarPrivate::qt_create_metaobjectdata<qt_meta_tag_ZN7Akonadi18ETMCalendarPrivateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi::ETMCalendarPrivate",
        "itemsFromModel",
        "Akonadi::Item::List",
        "",
        "const QAbstractItemModel*",
        "model",
        "QModelIndex",
        "parentIndex",
        "start",
        "end",
        "collectionsFromModel",
        "Akonadi::Collection::List",
        "onFilterChanged",
        "clear",
        "updateItem",
        "Akonadi::Item",
        "item",
        "itemFromIndex",
        "idx",
        "itemsAdded",
        "items",
        "itemsRemoved",
        "onRowsInserted",
        "index",
        "onRowsRemoved",
        "onDataChanged",
        "topLeft",
        "bottomRight",
        "onRowsMoved",
        "sourceParent",
        "sourceStart",
        "sourceEnd",
        "destinationParent",
        "destinationRow",
        "onLayoutChangedInFilteredModel",
        "onModelResetInFilteredModel",
        "onDataChangedInFilteredModel",
        "onRowsInsertedInFilteredModel",
        "onRowsAboutToBeRemovedInFilteredModel",
        "onCollectionChanged",
        "Akonadi::Collection",
        "collection",
        "QSet<QByteArray>",
        "attributeNames",
        "onCollectionPopulated",
        "Akonadi::Collection::Id",
        "updateLoadingState"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'itemsFromModel'
        QtMocHelpers::SlotData<Akonadi::Item::List(const QAbstractItemModel *, const QModelIndex &, int, int)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 }, { QMetaType::Int, 8 }, { QMetaType::Int, 9 },
        }}),
        // Slot 'itemsFromModel'
        QtMocHelpers::SlotData<Akonadi::Item::List(const QAbstractItemModel *, const QModelIndex &, int)>(1, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 }, { QMetaType::Int, 8 },
        }}),
        // Slot 'itemsFromModel'
        QtMocHelpers::SlotData<Akonadi::Item::List(const QAbstractItemModel *, const QModelIndex &)>(1, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'itemsFromModel'
        QtMocHelpers::SlotData<Akonadi::Item::List(const QAbstractItemModel *)>(1, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'collectionsFromModel'
        QtMocHelpers::SlotData<Akonadi::Collection::List(const QAbstractItemModel *, const QModelIndex &, int, int)>(10, 3, QMC::AccessPublic, 0x80000000 | 11, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 }, { QMetaType::Int, 8 }, { QMetaType::Int, 9 },
        }}),
        // Slot 'collectionsFromModel'
        QtMocHelpers::SlotData<Akonadi::Collection::List(const QAbstractItemModel *, const QModelIndex &, int)>(10, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 11, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 }, { QMetaType::Int, 8 },
        }}),
        // Slot 'collectionsFromModel'
        QtMocHelpers::SlotData<Akonadi::Collection::List(const QAbstractItemModel *, const QModelIndex &)>(10, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 11, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'collectionsFromModel'
        QtMocHelpers::SlotData<Akonadi::Collection::List(const QAbstractItemModel *)>(10, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 11, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'onFilterChanged'
        QtMocHelpers::SlotData<void()>(12, 3, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(13, 3, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateItem'
        QtMocHelpers::SlotData<void(const Akonadi::Item &)>(14, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'itemFromIndex'
        QtMocHelpers::SlotData<Akonadi::Item(const QModelIndex &)>(17, 3, QMC::AccessPublic, 0x80000000 | 15, {{
            { 0x80000000 | 6, 18 },
        }}),
        // Slot 'itemsAdded'
        QtMocHelpers::SlotData<void(const Akonadi::Item::List &)>(19, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 2, 20 },
        }}),
        // Slot 'itemsRemoved'
        QtMocHelpers::SlotData<void(const Akonadi::Item::List &)>(21, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 2, 20 },
        }}),
        // Slot 'onRowsInserted'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(22, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 23 }, { QMetaType::Int, 8 }, { QMetaType::Int, 9 },
        }}),
        // Slot 'onRowsRemoved'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(24, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 23 }, { QMetaType::Int, 8 }, { QMetaType::Int, 9 },
        }}),
        // Slot 'onDataChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &)>(25, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 26 }, { 0x80000000 | 6, 27 },
        }}),
        // Slot 'onRowsMoved'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int, const QModelIndex &, int)>(28, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 29 }, { QMetaType::Int, 30 }, { QMetaType::Int, 31 }, { 0x80000000 | 6, 32 },
            { QMetaType::Int, 33 },
        }}),
        // Slot 'onLayoutChangedInFilteredModel'
        QtMocHelpers::SlotData<void()>(34, 3, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onModelResetInFilteredModel'
        QtMocHelpers::SlotData<void()>(35, 3, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onDataChangedInFilteredModel'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &)>(36, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 26 }, { 0x80000000 | 6, 27 },
        }}),
        // Slot 'onRowsInsertedInFilteredModel'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(37, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 23 }, { QMetaType::Int, 8 }, { QMetaType::Int, 9 },
        }}),
        // Slot 'onRowsAboutToBeRemovedInFilteredModel'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(38, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 23 }, { QMetaType::Int, 8 }, { QMetaType::Int, 9 },
        }}),
        // Slot 'onCollectionChanged'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &, const QSet<QByteArray> &)>(39, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 40, 41 }, { 0x80000000 | 42, 43 },
        }}),
        // Slot 'onCollectionPopulated'
        QtMocHelpers::SlotData<void(Akonadi::Collection::Id)>(44, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 45, 3 },
        }}),
        // Slot 'updateLoadingState'
        QtMocHelpers::SlotData<void()>(46, 3, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ETMCalendarPrivate, qt_meta_tag_ZN7Akonadi18ETMCalendarPrivateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Akonadi::ETMCalendarPrivate::staticMetaObject = { {
    QMetaObject::SuperData::link<CalendarBasePrivate::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi18ETMCalendarPrivateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi18ETMCalendarPrivateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Akonadi18ETMCalendarPrivateE_t>.metaTypes,
    nullptr
} };

void Akonadi::ETMCalendarPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ETMCalendarPrivate *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { Akonadi::Item::List _r = _t->itemsFromModel((*reinterpret_cast<std::add_pointer_t<const QAbstractItemModel*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])));
            if (_a[0]) *reinterpret_cast<Akonadi::Item::List*>(_a[0]) = std::move(_r); }  break;
        case 1: { Akonadi::Item::List _r = _t->itemsFromModel((*reinterpret_cast<std::add_pointer_t<const QAbstractItemModel*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<Akonadi::Item::List*>(_a[0]) = std::move(_r); }  break;
        case 2: { Akonadi::Item::List _r = _t->itemsFromModel((*reinterpret_cast<std::add_pointer_t<const QAbstractItemModel*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Akonadi::Item::List*>(_a[0]) = std::move(_r); }  break;
        case 3: { Akonadi::Item::List _r = _t->itemsFromModel((*reinterpret_cast<std::add_pointer_t<const QAbstractItemModel*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Akonadi::Item::List*>(_a[0]) = std::move(_r); }  break;
        case 4: { Akonadi::Collection::List _r = _t->collectionsFromModel((*reinterpret_cast<std::add_pointer_t<const QAbstractItemModel*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])));
            if (_a[0]) *reinterpret_cast<Akonadi::Collection::List*>(_a[0]) = std::move(_r); }  break;
        case 5: { Akonadi::Collection::List _r = _t->collectionsFromModel((*reinterpret_cast<std::add_pointer_t<const QAbstractItemModel*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<Akonadi::Collection::List*>(_a[0]) = std::move(_r); }  break;
        case 6: { Akonadi::Collection::List _r = _t->collectionsFromModel((*reinterpret_cast<std::add_pointer_t<const QAbstractItemModel*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Akonadi::Collection::List*>(_a[0]) = std::move(_r); }  break;
        case 7: { Akonadi::Collection::List _r = _t->collectionsFromModel((*reinterpret_cast<std::add_pointer_t<const QAbstractItemModel*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Akonadi::Collection::List*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->onFilterChanged(); break;
        case 9: _t->clear(); break;
        case 10: _t->updateItem((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 11: { Akonadi::Item _r = _t->itemFromIndex((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Akonadi::Item*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->itemsAdded((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1]))); break;
        case 13: _t->itemsRemoved((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1]))); break;
        case 14: _t->onRowsInserted((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 15: _t->onRowsRemoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 16: _t->onDataChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 17: _t->onRowsMoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 18: _t->onLayoutChangedInFilteredModel(); break;
        case 19: _t->onModelResetInFilteredModel(); break;
        case 20: _t->onDataChangedInFilteredModel((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 21: _t->onRowsInsertedInFilteredModel((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 22: _t->onRowsAboutToBeRemovedInFilteredModel((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 23: _t->onCollectionChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSet<QByteArray>>>(_a[2]))); break;
        case 24: _t->onCollectionPopulated((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection::Id>>(_a[1]))); break;
        case 25: _t->updateLoadingState(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSet<QByteArray> >(); break;
            }
            break;
        }
    }
}

const QMetaObject *Akonadi::ETMCalendarPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi::ETMCalendarPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi18ETMCalendarPrivateE_t>.strings))
        return static_cast<void*>(this);
    return CalendarBasePrivate::qt_metacast(_clname);
}

int Akonadi::ETMCalendarPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = CalendarBasePrivate::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    return _id;
}
QT_WARNING_POP
