/****************************************************************************
** Meta object code from reading C++ file 'calendarsettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../calendarsettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'calendarsettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Akonadi16CalendarSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi::CalendarSettings::qt_create_metaobjectdata<qt_meta_tag_ZN7Akonadi16CalendarSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi::CalendarSettings",
        "FreeBusyPublishAutoChanged",
        "",
        "FreeBusyPublishDelayChanged",
        "FreeBusyPublishDaysChanged",
        "FreeBusyPublishUrlChanged",
        "FreeBusyPublishUserChanged",
        "FreeBusyPublishPasswordChanged",
        "FreeBusyPublishSavePasswordChanged",
        "FreeBusyRetrieveAutoChanged",
        "FreeBusyFullDomainRetrievalChanged",
        "FreeBusyRetrieveUrlChanged",
        "FreeBusyRetrieveUserChanged",
        "FreeBusyRetrievePasswordChanged",
        "FreeBusyRetrieveSavePasswordChanged",
        "BccChanged",
        "HideDeclinedInvitationsChanged",
        "OnlyShowRemindersForMyEventsChanged",
        "OutlookCompatCounterProposalsChanged",
        "FreeBusyCheckHostnameChanged",
        "freeBusyPublishAuto",
        "isFreeBusyPublishAutoImmutable",
        "freeBusyPublishDelay",
        "isFreeBusyPublishDelayImmutable",
        "freeBusyPublishDays",
        "isFreeBusyPublishDaysImmutable",
        "freeBusyPublishUrl",
        "isFreeBusyPublishUrlImmutable",
        "freeBusyPublishUser",
        "isFreeBusyPublishUserImmutable",
        "freeBusyPublishPassword",
        "isFreeBusyPublishPasswordImmutable",
        "freeBusyPublishSavePassword",
        "isFreeBusyPublishSavePasswordImmutable",
        "freeBusyRetrieveAuto",
        "isFreeBusyRetrieveAutoImmutable",
        "freeBusyFullDomainRetrieval",
        "isFreeBusyFullDomainRetrievalImmutable",
        "freeBusyRetrieveUrl",
        "isFreeBusyRetrieveUrlImmutable",
        "freeBusyRetrieveUser",
        "isFreeBusyRetrieveUserImmutable",
        "freeBusyRetrievePassword",
        "isFreeBusyRetrievePasswordImmutable",
        "freeBusyRetrieveSavePassword",
        "isFreeBusyRetrieveSavePasswordImmutable",
        "bcc",
        "isBccImmutable",
        "hideDeclinedInvitations",
        "isHideDeclinedInvitationsImmutable",
        "onlyShowRemindersForMyEvents",
        "isOnlyShowRemindersForMyEventsImmutable",
        "outlookCompatCounterProposals",
        "isOutlookCompatCounterProposalsImmutable",
        "freeBusyCheckHostname",
        "isFreeBusyCheckHostnameImmutable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'FreeBusyPublishAutoChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FreeBusyPublishDelayChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FreeBusyPublishDaysChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FreeBusyPublishUrlChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FreeBusyPublishUserChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FreeBusyPublishPasswordChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FreeBusyPublishSavePasswordChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FreeBusyRetrieveAutoChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FreeBusyFullDomainRetrievalChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FreeBusyRetrieveUrlChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FreeBusyRetrieveUserChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FreeBusyRetrievePasswordChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FreeBusyRetrieveSavePasswordChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'BccChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HideDeclinedInvitationsChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'OnlyShowRemindersForMyEventsChanged'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'OutlookCompatCounterProposalsChanged'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FreeBusyCheckHostnameChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'freeBusyPublishAuto'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isFreeBusyPublishAutoImmutable'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'freeBusyPublishDelay'
        QtMocHelpers::PropertyData<int>(22, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isFreeBusyPublishDelayImmutable'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'freeBusyPublishDays'
        QtMocHelpers::PropertyData<int>(24, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isFreeBusyPublishDaysImmutable'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'freeBusyPublishUrl'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isFreeBusyPublishUrlImmutable'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'freeBusyPublishUser'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isFreeBusyPublishUserImmutable'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'freeBusyPublishPassword'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isFreeBusyPublishPasswordImmutable'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'freeBusyPublishSavePassword'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isFreeBusyPublishSavePasswordImmutable'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'freeBusyRetrieveAuto'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isFreeBusyRetrieveAutoImmutable'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'freeBusyFullDomainRetrieval'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isFreeBusyFullDomainRetrievalImmutable'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'freeBusyRetrieveUrl'
        QtMocHelpers::PropertyData<QString>(38, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isFreeBusyRetrieveUrlImmutable'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'freeBusyRetrieveUser'
        QtMocHelpers::PropertyData<QString>(40, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isFreeBusyRetrieveUserImmutable'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'freeBusyRetrievePassword'
        QtMocHelpers::PropertyData<QString>(42, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isFreeBusyRetrievePasswordImmutable'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'freeBusyRetrieveSavePassword'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isFreeBusyRetrieveSavePasswordImmutable'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bcc'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'isBccImmutable'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hideDeclinedInvitations'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'isHideDeclinedInvitationsImmutable'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'onlyShowRemindersForMyEvents'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'isOnlyShowRemindersForMyEventsImmutable'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'outlookCompatCounterProposals'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'isOutlookCompatCounterProposalsImmutable'
        QtMocHelpers::PropertyData<bool>(53, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'freeBusyCheckHostname'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'isFreeBusyCheckHostnameImmutable'
        QtMocHelpers::PropertyData<bool>(55, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CalendarSettings, qt_meta_tag_ZN7Akonadi16CalendarSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Akonadi::CalendarSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi16CalendarSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi16CalendarSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Akonadi16CalendarSettingsE_t>.metaTypes,
    nullptr
} };

void Akonadi::CalendarSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CalendarSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->FreeBusyPublishAutoChanged(); break;
        case 1: _t->FreeBusyPublishDelayChanged(); break;
        case 2: _t->FreeBusyPublishDaysChanged(); break;
        case 3: _t->FreeBusyPublishUrlChanged(); break;
        case 4: _t->FreeBusyPublishUserChanged(); break;
        case 5: _t->FreeBusyPublishPasswordChanged(); break;
        case 6: _t->FreeBusyPublishSavePasswordChanged(); break;
        case 7: _t->FreeBusyRetrieveAutoChanged(); break;
        case 8: _t->FreeBusyFullDomainRetrievalChanged(); break;
        case 9: _t->FreeBusyRetrieveUrlChanged(); break;
        case 10: _t->FreeBusyRetrieveUserChanged(); break;
        case 11: _t->FreeBusyRetrievePasswordChanged(); break;
        case 12: _t->FreeBusyRetrieveSavePasswordChanged(); break;
        case 13: _t->BccChanged(); break;
        case 14: _t->HideDeclinedInvitationsChanged(); break;
        case 15: _t->OnlyShowRemindersForMyEventsChanged(); break;
        case 16: _t->OutlookCompatCounterProposalsChanged(); break;
        case 17: _t->FreeBusyCheckHostnameChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CalendarSettings::*)()>(_a, &CalendarSettings::FreeBusyPublishAutoChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarSettings::*)()>(_a, &CalendarSettings::FreeBusyPublishDelayChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarSettings::*)()>(_a, &CalendarSettings::FreeBusyPublishDaysChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarSettings::*)()>(_a, &CalendarSettings::FreeBusyPublishUrlChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarSettings::*)()>(_a, &CalendarSettings::FreeBusyPublishUserChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarSettings::*)()>(_a, &CalendarSettings::FreeBusyPublishPasswordChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarSettings::*)()>(_a, &CalendarSettings::FreeBusyPublishSavePasswordChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarSettings::*)()>(_a, &CalendarSettings::FreeBusyRetrieveAutoChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarSettings::*)()>(_a, &CalendarSettings::FreeBusyFullDomainRetrievalChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarSettings::*)()>(_a, &CalendarSettings::FreeBusyRetrieveUrlChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarSettings::*)()>(_a, &CalendarSettings::FreeBusyRetrieveUserChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarSettings::*)()>(_a, &CalendarSettings::FreeBusyRetrievePasswordChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarSettings::*)()>(_a, &CalendarSettings::FreeBusyRetrieveSavePasswordChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarSettings::*)()>(_a, &CalendarSettings::BccChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarSettings::*)()>(_a, &CalendarSettings::HideDeclinedInvitationsChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarSettings::*)()>(_a, &CalendarSettings::OnlyShowRemindersForMyEventsChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarSettings::*)()>(_a, &CalendarSettings::OutlookCompatCounterProposalsChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarSettings::*)()>(_a, &CalendarSettings::FreeBusyCheckHostnameChanged, 17))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->freeBusyPublishAuto(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isFreeBusyPublishAutoImmutable(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->freeBusyPublishDelay(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isFreeBusyPublishDelayImmutable(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->freeBusyPublishDays(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isFreeBusyPublishDaysImmutable(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->freeBusyPublishUrl(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isFreeBusyPublishUrlImmutable(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->freeBusyPublishUser(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isFreeBusyPublishUserImmutable(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->freeBusyPublishPassword(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->isFreeBusyPublishPasswordImmutable(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->freeBusyPublishSavePassword(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isFreeBusyPublishSavePasswordImmutable(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->freeBusyRetrieveAuto(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->isFreeBusyRetrieveAutoImmutable(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->freeBusyFullDomainRetrieval(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->isFreeBusyFullDomainRetrievalImmutable(); break;
        case 18: *reinterpret_cast<QString*>(_v) = _t->freeBusyRetrieveUrl(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isFreeBusyRetrieveUrlImmutable(); break;
        case 20: *reinterpret_cast<QString*>(_v) = _t->freeBusyRetrieveUser(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->isFreeBusyRetrieveUserImmutable(); break;
        case 22: *reinterpret_cast<QString*>(_v) = _t->freeBusyRetrievePassword(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->isFreeBusyRetrievePasswordImmutable(); break;
        case 24: *reinterpret_cast<bool*>(_v) = _t->freeBusyRetrieveSavePassword(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isFreeBusyRetrieveSavePasswordImmutable(); break;
        case 26: *reinterpret_cast<bool*>(_v) = _t->bcc(); break;
        case 27: *reinterpret_cast<bool*>(_v) = _t->isBccImmutable(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->hideDeclinedInvitations(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->isHideDeclinedInvitationsImmutable(); break;
        case 30: *reinterpret_cast<bool*>(_v) = _t->onlyShowRemindersForMyEvents(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isOnlyShowRemindersForMyEventsImmutable(); break;
        case 32: *reinterpret_cast<bool*>(_v) = _t->outlookCompatCounterProposals(); break;
        case 33: *reinterpret_cast<bool*>(_v) = _t->isOutlookCompatCounterProposalsImmutable(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->freeBusyCheckHostname(); break;
        case 35: *reinterpret_cast<bool*>(_v) = _t->isFreeBusyCheckHostnameImmutable(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFreeBusyPublishAuto(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setFreeBusyPublishDelay(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setFreeBusyPublishDays(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setFreeBusyPublishUrl(*reinterpret_cast<QString*>(_v)); break;
        case 8: _t->setFreeBusyPublishUser(*reinterpret_cast<QString*>(_v)); break;
        case 10: _t->setFreeBusyPublishPassword(*reinterpret_cast<QString*>(_v)); break;
        case 12: _t->setFreeBusyPublishSavePassword(*reinterpret_cast<bool*>(_v)); break;
        case 14: _t->setFreeBusyRetrieveAuto(*reinterpret_cast<bool*>(_v)); break;
        case 16: _t->setFreeBusyFullDomainRetrieval(*reinterpret_cast<bool*>(_v)); break;
        case 18: _t->setFreeBusyRetrieveUrl(*reinterpret_cast<QString*>(_v)); break;
        case 20: _t->setFreeBusyRetrieveUser(*reinterpret_cast<QString*>(_v)); break;
        case 22: _t->setFreeBusyRetrievePassword(*reinterpret_cast<QString*>(_v)); break;
        case 24: _t->setFreeBusyRetrieveSavePassword(*reinterpret_cast<bool*>(_v)); break;
        case 26: _t->setBcc(*reinterpret_cast<bool*>(_v)); break;
        case 28: _t->setHideDeclinedInvitations(*reinterpret_cast<bool*>(_v)); break;
        case 30: _t->setOnlyShowRemindersForMyEvents(*reinterpret_cast<bool*>(_v)); break;
        case 32: _t->setOutlookCompatCounterProposals(*reinterpret_cast<bool*>(_v)); break;
        case 34: _t->setFreeBusyCheckHostname(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Akonadi::CalendarSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi::CalendarSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi16CalendarSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int Akonadi::CalendarSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 36;
    }
    return _id;
}

// SIGNAL 0
void Akonadi::CalendarSettings::FreeBusyPublishAutoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Akonadi::CalendarSettings::FreeBusyPublishDelayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Akonadi::CalendarSettings::FreeBusyPublishDaysChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Akonadi::CalendarSettings::FreeBusyPublishUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Akonadi::CalendarSettings::FreeBusyPublishUserChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Akonadi::CalendarSettings::FreeBusyPublishPasswordChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Akonadi::CalendarSettings::FreeBusyPublishSavePasswordChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Akonadi::CalendarSettings::FreeBusyRetrieveAutoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Akonadi::CalendarSettings::FreeBusyFullDomainRetrievalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Akonadi::CalendarSettings::FreeBusyRetrieveUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Akonadi::CalendarSettings::FreeBusyRetrieveUserChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Akonadi::CalendarSettings::FreeBusyRetrievePasswordChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Akonadi::CalendarSettings::FreeBusyRetrieveSavePasswordChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Akonadi::CalendarSettings::BccChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Akonadi::CalendarSettings::HideDeclinedInvitationsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void Akonadi::CalendarSettings::OnlyShowRemindersForMyEventsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void Akonadi::CalendarSettings::OutlookCompatCounterProposalsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void Akonadi::CalendarSettings::FreeBusyCheckHostnameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}
QT_WARNING_POP
