/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.Resource.FreeBusyProvider.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef FREEBUSYPROVIDERADAPTOR_H
#define FREEBUSYPROVIDERADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "freebusyproviderbase_p.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.freedesktop.Akonadi.Resource.FreeBusyProvider
 */
class Akonadi__FreeBusyProviderAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.freedesktop.Akonadi.Resource.FreeBusyProvider")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.freedesktop.Akonadi.Resource.FreeBusyProvider\">\n"
"    <method name=\"lastCacheUpdate\">\n"
"      <arg direction=\"out\" type=\"((iii)(iiii)i)\"/>\n"
"      <annotation value=\"QDateTime\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </method>\n"
"    <method name=\"canHandleFreeBusy\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"email\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"retrieveFreeBusy\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"email\"/>\n"
"      <arg direction=\"in\" type=\"((iii)(iiii)i)\" name=\"start\"/>\n"
"      <arg direction=\"in\" type=\"((iii)(iiii)i)\" name=\"end\"/>\n"
"      <annotation value=\"QDateTime\" name=\"org.qtproject.QtDBus.QtTypeName.In1\"/>\n"
"      <annotation value=\"QDateTime\" name=\"org.qtproject.QtDBus.QtTypeName.In2\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <signal name=\"handlesFreeBusy\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"email\"/>\n"
"      <arg direction=\"out\" type=\"b\" name=\"handles\"/>\n"
"    </signal>\n"
"    <signal name=\"freeBusyRetrieved\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"email\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"freeBusy\"/>\n"
"      <arg direction=\"out\" type=\"b\" name=\"success\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"errorText\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    Akonadi__FreeBusyProviderAdaptor(Akonadi::FreeBusyProviderBasePrivate *parent);
    ~Akonadi__FreeBusyProviderAdaptor() override;

    inline Akonadi::FreeBusyProviderBasePrivate *parent() const
    { return static_cast<Akonadi::FreeBusyProviderBasePrivate *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    Q_NOREPLY void canHandleFreeBusy(const QString &email);
    QDateTime lastCacheUpdate();
    Q_NOREPLY void retrieveFreeBusy(const QString &email, const QDateTime &start, const QDateTime &end);
Q_SIGNALS: // SIGNALS
    void freeBusyRetrieved(const QString &email, const QString &freeBusy, bool success, const QString &errorText);
    void handlesFreeBusy(const QString &email, bool handles);
};

#endif
