/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.Resource.FreeBusyProvider.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "freebusyprovideradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class Akonadi__FreeBusyProviderAdaptor
 */

Akonadi__FreeBusyProviderAdaptor::Akonadi__FreeBusyProviderAdaptor(Akonadi::FreeBusyProviderBasePrivate *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

Akonadi__FreeBusyProviderAdaptor::~Akonadi__FreeBusyProviderAdaptor()
{
    // destructor
}

void Akonadi__FreeBusyProviderAdaptor::canHandleFreeBusy(const QString &email)
{
    // handle method call org.freedesktop.Akonadi.Resource.FreeBusyProvider.canHandleFreeBusy
    parent()->canHandleFreeBusy(email);
}

QDateTime Akonadi__FreeBusyProviderAdaptor::lastCacheUpdate()
{
    // handle method call org.freedesktop.Akonadi.Resource.FreeBusyProvider.lastCacheUpdate
    return parent()->lastCacheUpdate();
}

void Akonadi__FreeBusyProviderAdaptor::retrieveFreeBusy(const QString &email, const QDateTime &start, const QDateTime &end)
{
    // handle method call org.freedesktop.Akonadi.Resource.FreeBusyProvider.retrieveFreeBusy
    parent()->retrieveFreeBusy(email, start, end);
}


#include "moc_freebusyprovideradaptor.cpp"
