/****************************************************************************
** Meta object code from reading C++ file 'incidencechanger_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../akonadi-calendar-26.04.3/src/incidencechanger_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'incidencechanger_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Akonadi6ChangeE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi::Change::qt_create_metaobjectdata<qt_meta_tag_ZN7Akonadi6ChangeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi::Change",
        "dialogClosedBeforeChange",
        "",
        "id",
        "Akonadi::ITIPHandlerHelper::SendResult",
        "status",
        "dialogClosedAfterChange",
        "emitUserDialogClosedAfterChange",
        "emitUserDialogClosedBeforeChange"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dialogClosedBeforeChange'
        QtMocHelpers::SignalData<void(int, Akonadi::ITIPHandlerHelper::SendResult)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'dialogClosedAfterChange'
        QtMocHelpers::SignalData<void(int, Akonadi::ITIPHandlerHelper::SendResult)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Slot 'emitUserDialogClosedAfterChange'
        QtMocHelpers::SlotData<void(Akonadi::ITIPHandlerHelper::SendResult)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'emitUserDialogClosedBeforeChange'
        QtMocHelpers::SlotData<void(Akonadi::ITIPHandlerHelper::SendResult)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Change, qt_meta_tag_ZN7Akonadi6ChangeE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Akonadi::Change::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi6ChangeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi6ChangeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Akonadi6ChangeE_t>.metaTypes,
    nullptr
} };

void Akonadi::Change::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Change *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dialogClosedBeforeChange((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::ITIPHandlerHelper::SendResult>>(_a[2]))); break;
        case 1: _t->dialogClosedAfterChange((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::ITIPHandlerHelper::SendResult>>(_a[2]))); break;
        case 2: _t->emitUserDialogClosedAfterChange((*reinterpret_cast<std::add_pointer_t<Akonadi::ITIPHandlerHelper::SendResult>>(_a[1]))); break;
        case 3: _t->emitUserDialogClosedBeforeChange((*reinterpret_cast<std::add_pointer_t<Akonadi::ITIPHandlerHelper::SendResult>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Change::*)(int , Akonadi::ITIPHandlerHelper::SendResult )>(_a, &Change::dialogClosedBeforeChange, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Change::*)(int , Akonadi::ITIPHandlerHelper::SendResult )>(_a, &Change::dialogClosedAfterChange, 1))
            return;
    }
}

const QMetaObject *Akonadi::Change::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi::Change::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi6ChangeE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Akonadi::Change::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void Akonadi::Change::dialogClosedBeforeChange(int _t1, Akonadi::ITIPHandlerHelper::SendResult _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Akonadi::Change::dialogClosedAfterChange(int _t1, Akonadi::ITIPHandlerHelper::SendResult _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN7Akonadi18ModificationChangeE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi::ModificationChange::qt_create_metaobjectdata<qt_meta_tag_ZN7Akonadi18ModificationChangeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi::ModificationChange"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ModificationChange, qt_meta_tag_ZN7Akonadi18ModificationChangeE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Akonadi::ModificationChange::staticMetaObject = { {
    QMetaObject::SuperData::link<Change::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi18ModificationChangeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi18ModificationChangeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Akonadi18ModificationChangeE_t>.metaTypes,
    nullptr
} };

void Akonadi::ModificationChange::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ModificationChange *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Akonadi::ModificationChange::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi::ModificationChange::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi18ModificationChangeE_t>.strings))
        return static_cast<void*>(this);
    return Change::qt_metacast(_clname);
}

int Akonadi::ModificationChange::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Change::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN7Akonadi14CreationChangeE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi::CreationChange::qt_create_metaobjectdata<qt_meta_tag_ZN7Akonadi14CreationChangeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi::CreationChange"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CreationChange, qt_meta_tag_ZN7Akonadi14CreationChangeE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Akonadi::CreationChange::staticMetaObject = { {
    QMetaObject::SuperData::link<Change::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi14CreationChangeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi14CreationChangeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Akonadi14CreationChangeE_t>.metaTypes,
    nullptr
} };

void Akonadi::CreationChange::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CreationChange *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Akonadi::CreationChange::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi::CreationChange::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi14CreationChangeE_t>.strings))
        return static_cast<void*>(this);
    return Change::qt_metacast(_clname);
}

int Akonadi::CreationChange::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Change::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN7Akonadi14DeletionChangeE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi::DeletionChange::qt_create_metaobjectdata<qt_meta_tag_ZN7Akonadi14DeletionChangeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi::DeletionChange"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DeletionChange, qt_meta_tag_ZN7Akonadi14DeletionChangeE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Akonadi::DeletionChange::staticMetaObject = { {
    QMetaObject::SuperData::link<Change::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi14DeletionChangeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi14DeletionChangeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Akonadi14DeletionChangeE_t>.metaTypes,
    nullptr
} };

void Akonadi::DeletionChange::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeletionChange *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Akonadi::DeletionChange::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi::DeletionChange::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi14DeletionChangeE_t>.strings))
        return static_cast<void*>(this);
    return Change::qt_metacast(_clname);
}

int Akonadi::DeletionChange::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Change::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN7Akonadi23IncidenceChangerPrivateE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi::IncidenceChangerPrivate::qt_create_metaobjectdata<qt_meta_tag_ZN7Akonadi23IncidenceChangerPrivateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi::IncidenceChangerPrivate",
        "handleCreateJobResult",
        "",
        "KJob*",
        "job",
        "handleModifyJobResult",
        "handleDeleteJobResult",
        "handleTransactionJobResult",
        "performNextModification",
        "Akonadi::Item::Id",
        "id",
        "onCollectionsLoaded",
        "handleCreateJobResult2",
        "changeId",
        "Akonadi::ITIPHandlerHelper::SendResult",
        "handleDeleteJobResult2",
        "handleModifyJobResult2",
        "performModification2",
        "deleteIncidences2"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'handleCreateJobResult'
        QtMocHelpers::SlotData<void(KJob *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'handleModifyJobResult'
        QtMocHelpers::SlotData<void(KJob *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'handleDeleteJobResult'
        QtMocHelpers::SlotData<void(KJob *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'handleTransactionJobResult'
        QtMocHelpers::SlotData<void(KJob *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'performNextModification'
        QtMocHelpers::SlotData<void(Akonadi::Item::Id)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'onCollectionsLoaded'
        QtMocHelpers::SlotData<void(KJob *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'handleCreateJobResult2'
        QtMocHelpers::SlotData<void(int, Akonadi::ITIPHandlerHelper::SendResult)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 }, { 0x80000000 | 14, 2 },
        }}),
        // Slot 'handleDeleteJobResult2'
        QtMocHelpers::SlotData<void(int, Akonadi::ITIPHandlerHelper::SendResult)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 }, { 0x80000000 | 14, 2 },
        }}),
        // Slot 'handleModifyJobResult2'
        QtMocHelpers::SlotData<void(int, Akonadi::ITIPHandlerHelper::SendResult)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 }, { 0x80000000 | 14, 2 },
        }}),
        // Slot 'performModification2'
        QtMocHelpers::SlotData<void(int, Akonadi::ITIPHandlerHelper::SendResult)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 }, { 0x80000000 | 14, 2 },
        }}),
        // Slot 'deleteIncidences2'
        QtMocHelpers::SlotData<void(int, Akonadi::ITIPHandlerHelper::SendResult)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 }, { 0x80000000 | 14, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<IncidenceChangerPrivate, qt_meta_tag_ZN7Akonadi23IncidenceChangerPrivateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Akonadi::IncidenceChangerPrivate::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi23IncidenceChangerPrivateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi23IncidenceChangerPrivateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Akonadi23IncidenceChangerPrivateE_t>.metaTypes,
    nullptr
} };

void Akonadi::IncidenceChangerPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IncidenceChangerPrivate *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->handleCreateJobResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 1: _t->handleModifyJobResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 2: _t->handleDeleteJobResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 3: _t->handleTransactionJobResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 4: _t->performNextModification((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::Id>>(_a[1]))); break;
        case 5: _t->onCollectionsLoaded((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 6: _t->handleCreateJobResult2((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::ITIPHandlerHelper::SendResult>>(_a[2]))); break;
        case 7: _t->handleDeleteJobResult2((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::ITIPHandlerHelper::SendResult>>(_a[2]))); break;
        case 8: _t->handleModifyJobResult2((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::ITIPHandlerHelper::SendResult>>(_a[2]))); break;
        case 9: _t->performModification2((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::ITIPHandlerHelper::SendResult>>(_a[2]))); break;
        case 10: _t->deleteIncidences2((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::ITIPHandlerHelper::SendResult>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *Akonadi::IncidenceChangerPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi::IncidenceChangerPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi23IncidenceChangerPrivateE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Akonadi::IncidenceChangerPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}
QT_WARNING_POP
